
# Ceridian Connector

> Dayforce enterprise HCM software combines payroll, HR, benefits, talent and workforce management in a single cloud application to power the future of work.Ceridian


🔗 https://www.ceridian.com/

| Actions |
| ------- |
| [**Pull jobs**](docs/pull_jobs.md) |
